agentle.agents.execution\_state
===============================

.. automodule:: agentle.agents.execution_state

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      ExecutionState
      MutableMapping
      datetime
   